@@ -6,7 +6,7 @@
 
 #define RAV1E_MAJOR 0
 #define RAV1E_MINOR 3
-#define RAV1E_PATCH 4
+#define RAV1E_PATCH 5
 
 
 #include <stddef.h>
@@ -379,35 +379,6 @@ typedef struct RaContext RaContext;
  */
 typedef struct RaFrame RaFrame;
 
-/**
- * Chromaticity coordinates as defined by CIE 1931, expressed as 0.16
- * fixed-point values.
- */
-typedef struct {
-    /**
-     * The X coordinate.
-     */
-    uint16_t x;
-    /**
-     * The Y coordinate.
-     */
-    uint16_t y;
-} RaChromaticityPoint;
-
-/**
- * A rational number.
- */
-typedef struct {
-    /**
-     * Numerator.
-     */
-    uint64_t num;
-    /**
-     * Denominator.
-     */
-    uint64_t den;
-} RaRational;
-
 /**
  * Simple Data
  *
@@ -426,6 +397,35 @@ typedef struct {
     size_t len;
 } RaData;
 
+/**
+ * A rational number.
+ */
+typedef struct {
+    /**
+     * Numerator.
+     */
+    uint64_t num;
+    /**
+     * Denominator.
+     */
+    uint64_t den;
+} RaRational;
+
+/**
+ * Chromaticity coordinates as defined by CIE 1931, expressed as 0.16
+ * fixed-point values.
+ */
+typedef struct {
+    /**
+     * The X coordinate.
+     */
+    uint16_t x;
+    /**
+     * The Y coordinate.
+     */
+    uint16_t y;
+} RaChromaticityPoint;
+
 /**
  * Encoded Packet
  *
@@ -456,31 +456,59 @@ typedef struct {
 extern "C" {
 #endif // __cplusplus
 
+/**
+ * Version information as presented in `[package]` `version`.
+ *
+ * e.g. `0.1.0``
+ *
+ * Can be parsed by [semver](https://crates.io/crates/semver).
+ * This returns the version of the loaded library, regardless
+ * of which version the library user was built against.
+ */
+const char *rav1e_version_short(void);
+
+/**
+ * Version information with the information
+ * provided by `git describe --tags`.
+ *
+ * e.g. `0.1.0 (v0.1.0-1-g743d464)`
+ *
+ * This returns the version of the loaded library, regardless
+ * of which version the library user was built against.
+ */
+const char *rav1e_version_full(void);
+
+/**
+ * Free a RaData buffer
+ */
+void rav1e_data_unref(RaData *data);
+
 /**
  * Create a RaConfig filled with default parameters.
  */
 RaConfig *rav1e_config_default(void);
 
 /**
- * Set a configuration parameter using its key and value as string.
+ * Set the time base of the stream
  *
- * Available keys and values
- * - "quantizer": 0-255, default 100
- * - "speed": 0-10, default 6
- * - "tune": "psnr"-"psychovisual", default "psychovisual"
- *
- * Return a negative value on error or 0.
+ * Needed for rate control.
  */
-int rav1e_config_parse(RaConfig *cfg, const char *key, const char *value);
+void rav1e_config_set_time_base(RaConfig *cfg, RaRational time_base);
 
 /**
- * Set a configuration parameter using its key and value as integer.
+ * Set pixel format of the stream.
  *
- * Available keys and values are the same as rav1e_config_parse()
+ * Supported values for subsampling and chromapos are defined by the
+ * enum types RaChromaSampling and RaChromaSamplePosition respectively.
+ * Valid values for fullrange are 0 and 1.
  *
- * Return a negative value on error or 0.
+ * Returns a negative value on error or 0.
  */
-int rav1e_config_parse_int(RaConfig *cfg, const char *key, int value);
+int rav1e_config_set_pixel_format(RaConfig *cfg,
+                                  uint8_t bit_depth,
+                                  RaChromaSampling subsampling,
+                                  RaChromaSamplePosition chroma_pos,
+                                  RaPixelRange pixel_range);
 
 /**
  * Set color properties of the stream.
@@ -516,46 +544,36 @@ int rav1e_config_set_content_light(RaConfig *cfg,
  * Returns a negative value on error or 0.
  */
 int rav1e_config_set_mastering_display(RaConfig *cfg,
-                                       const RaChromaticityPoint *primaries,
+                                       const RaChromaticityPoint primaries[3],
                                        RaChromaticityPoint white_point,
                                        uint32_t max_luminance,
                                        uint32_t min_luminance);
 
-/**
- * Set pixel format of the stream.
- *
- * Supported values for subsampling and chromapos are defined by the
- * enum types RaChromaSampling and RaChromaSamplePosition respectively.
- * Valid values for fullrange are 0 and 1.
- *
- * Returns a negative value on error or 0.
- */
-int rav1e_config_set_pixel_format(RaConfig *cfg,
-                                  uint8_t bit_depth,
-                                  RaChromaSampling subsampling,
-                                  RaChromaSamplePosition chroma_pos,
-                                  RaPixelRange pixel_range);
-
-/**
- * Set the time base of the stream
- *
- * Needed for rate control.
- */
-void rav1e_config_set_time_base(RaConfig *cfg, RaRational time_base);
-
 /**
  * Free the RaConfig.
  */
 void rav1e_config_unref(RaConfig *cfg);
 
 /**
- * Produce a sequence header matching the current encoding context
+ * Set a configuration parameter using its key and value as string.
  *
- * Its format is compatible with the AV1 Matroska and ISOBMFF specification.
+ * Available keys and values
+ * - "quantizer": 0-255, default 100
+ * - "speed": 0-10, default 6
+ * - "tune": "psnr"-"psychovisual", default "psychovisual"
  *
- * Use rav1e_data_unref() to free it.
+ * Return a negative value on error or 0.
  */
-RaData *rav1e_container_sequence_header(const RaContext *ctx);
+int rav1e_config_parse(RaConfig *cfg, const char *key, const char *value);
+
+/**
+ * Set a configuration parameter using its key and value as integer.
+ *
+ * Available keys and values are the same as rav1e_config_parse()
+ *
+ * Return a negative value on error or 0.
+ */
+int rav1e_config_parse_int(RaConfig *cfg, const char *key, int value);
 
 /**
  * Generate a new encoding context from a populated encoder configuration
@@ -571,33 +589,6 @@ RaContext *rav1e_context_new(const RaConfig *cfg);
  */
 void rav1e_context_unref(RaContext *ctx);
 
-/**
- * Free a RaData buffer
- */
-void rav1e_data_unref(RaData *data);
-
-/**
- * Fill a frame plane
- *
- * Currently the frame contains 3 planes, the first is luminance followed by
- * chrominance.
- *
- * The data is copied and this function has to be called for each plane.
- *
- * frame: A frame provided by rav1e_frame_new()
- * plane: The index of the plane starting from 0
- * data: The data to be copied
- * data_len: Length of the buffer
- * stride: Plane line in bytes, including padding
- * bytewidth: Number of bytes per component, either 1 or 2
- */
-void rav1e_frame_fill_plane(RaFrame *frame,
-                            int plane,
-                            const uint8_t *data,
-                            size_t data_len,
-                            ptrdiff_t stride,
-                            int bytewidth);
-
 /**
  * Produce a new frame from the encoding context
  *
@@ -608,6 +599,11 @@ void rav1e_frame_fill_plane(RaFrame *frame,
  */
 RaFrame *rav1e_frame_new(const RaContext *ctx);
 
+/**
+ * Free the RaFrame.
+ */
+void rav1e_frame_unref(RaFrame *frame);
+
 /**
  * Overrides the encoders frame type decision for a frame
  *
@@ -616,48 +612,22 @@ RaFrame *rav1e_frame_new(const RaContext *ctx);
 int rav1e_frame_set_type(RaFrame *frame, RaFrameTypeOverride frame_type);
 
 /**
- * Free the RaFrame.
- */
-void rav1e_frame_unref(RaFrame *frame);
-
-/**
- * Return the last encoder status
- */
-RaEncoderStatus rav1e_last_status(const RaContext *ctx);
-
-/**
- * Free the RaPacket.
- */
-void rav1e_packet_unref(RaPacket *pkt);
-
-/**
- * Receive encoded data
+ * Retrieve the first-pass data of a two-pass encode for the frame that was
+ * just encoded. This should be called BEFORE every call to rav1e_receive_packet()
+ * (including the very first one), even if no packet was produced by the
+ * last call to rav1e_receive_packet, if any (i.e., RA_ENCODER_STATUS_ENCODED
+ * was returned). It needs to be called once more after
+ * RA_ENCODER_STATUS_LIMIT_REACHED is returned, to retrieve the header that
+ * should be written to the front of the stats file (overwriting the
+ * placeholder header that was emitted at the start of encoding).
  *
- * Returns:
- * - `0` on success
- * - `> 0` if additional frame data is required
- * - `< 0` on unrecoverable failure
- */
-RaEncoderStatus rav1e_receive_packet(RaContext *ctx, RaPacket **pkt);
-
-/**
- * Send the frame for encoding
+ * It is still safe to call this function when rav1e_receive_packet() returns any
+ * other error. It will return NULL instead of returning a duplicate copy
+ * of the previous frame's data.
  *
- * The function increases the frame internal reference count and it can be passed multiple
- * times to different rav1e_send_frame().
- *
- * Returns:
- * - `0` on success,
- * - `> 0` if the input queue is full
- * - `< 0` on unrecoverable failure
+ * Must be freed with rav1e_data_unref().
  */
-RaEncoderStatus rav1e_send_frame(RaContext *ctx, const RaFrame *frame);
-
-/**
- * Return a static string matching the EncoderStatus variant.
- *
- */
-const char *rav1e_status_to_str(RaEncoderStatus status);
+RaData *rav1e_twopass_out(RaContext *ctx);
 
 /**
  * Ask how many bytes of the stats file are needed before the next frame
@@ -681,44 +651,74 @@ size_t rav1e_twopass_bytes_needed(RaContext *ctx);
 int rav1e_twopass_in(RaContext *ctx, uint8_t *buf, size_t buf_size);
 
 /**
- * Retrieve the first-pass data of a two-pass encode for the frame that was
- * just encoded. This should be called BEFORE every call to rav1e_receive_packet()
- * (including the very first one), even if no packet was produced by the
- * last call to rav1e_receive_packet, if any (i.e., RA_ENCODER_STATUS_ENCODED
- * was returned). It needs to be called once more after
- * RA_ENCODER_STATUS_LIMIT_REACHED is returned, to retrieve the header that
- * should be written to the front of the stats file (overwriting the
- * placeholder header that was emitted at the start of encoding).
+ * Send the frame for encoding
  *
- * It is still safe to call this function when rav1e_receive_packet() returns any
- * other error. It will return NULL instead of returning a duplicate copy
- * of the previous frame's data.
+ * The function increases the frame internal reference count and it can be passed multiple
+ * times to different rav1e_send_frame().
  *
- * Must be freed with rav1e_data_unref().
+ * Returns:
+ * - `0` on success,
+ * - `> 0` if the input queue is full
+ * - `< 0` on unrecoverable failure
  */
-RaData *rav1e_twopass_out(RaContext *ctx);
+RaEncoderStatus rav1e_send_frame(RaContext *ctx, const RaFrame *frame);
 
 /**
- * Version information with the information
- * provided by `git describe --tags`.
- *
- * e.g. `0.1.0 (v0.1.0-1-g743d464)`
- *
- * This returns the version of the loaded library, regardless
- * of which version the library user was built against.
+ * Return the last encoder status
  */
-const char *rav1e_version_full(void);
+RaEncoderStatus rav1e_last_status(const RaContext *ctx);
 
 /**
- * Version information as presented in `[package]` `version`.
+ * Return a static string matching the EncoderStatus variant.
  *
- * e.g. `0.1.0``
- *
- * Can be parsed by [semver](https://crates.io/crates/semver).
- * This returns the version of the loaded library, regardless
- * of which version the library user was built against.
  */
-const char *rav1e_version_short(void);
+const char *rav1e_status_to_str(RaEncoderStatus status);
+
+/**
+ * Receive encoded data
+ *
+ * Returns:
+ * - `0` on success
+ * - `> 0` if additional frame data is required
+ * - `< 0` on unrecoverable failure
+ */
+RaEncoderStatus rav1e_receive_packet(RaContext *ctx, RaPacket **pkt);
+
+/**
+ * Free the RaPacket.
+ */
+void rav1e_packet_unref(RaPacket *pkt);
+
+/**
+ * Produce a sequence header matching the current encoding context
+ *
+ * Its format is compatible with the AV1 Matroska and ISOBMFF specification.
+ *
+ * Use rav1e_data_unref() to free it.
+ */
+RaData *rav1e_container_sequence_header(const RaContext *ctx);
+
+/**
+ * Fill a frame plane
+ *
+ * Currently the frame contains 3 planes, the first is luminance followed by
+ * chrominance.
+ *
+ * The data is copied and this function has to be called for each plane.
+ *
+ * frame: A frame provided by rav1e_frame_new()
+ * plane: The index of the plane starting from 0
+ * data: The data to be copied
+ * data_len: Length of the buffer
+ * stride: Plane line in bytes, including padding
+ * bytewidth: Number of bytes per component, either 1 or 2
+ */
+void rav1e_frame_fill_plane(RaFrame *frame,
+                            int plane,
+                            const uint8_t *data,
+                            size_t data_len,
+                            ptrdiff_t stride,
+                            int bytewidth);
 
 #ifdef __cplusplus
 } // extern "C"
